/*
 * Copyright (c) 2007 Konopa-Jelen-Majer
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup FileSystemTask
 * @{
 */ 

/**
 * @file	message.h
 * @brief	Extended message structure, which is used for communicating between FS
 *        and its consuments.
 */

#ifndef _MESSAGE_H
#define _MESSAGE_H

/** 
 * Declaration of the extended message structure as it is in the call and buffer. 
 */
	typedef struct {
		ipcarg_t id_task;		/**< id of currently consument */
		ipcarg_t fd;			/**< file descriptor */
		ipcarg_t whence;		/**< start position of SEEK */

		/* Parameters which are present only in the buffer. */
		unsigned int nbytes;		/**< number of bytes which will be read */
		offset_t offset;		/**< offset of SEEK */
		char fname[DIRSIZEX];		/**< file name */
		int entry_number;		/**< number of directory entry */
	} message_params_t;

#endif /* _MESSAGE_H */

/**
 *}
 */
   
